USE [igops]
GO

DROP VIEW IF EXISTS risk_score_calculation_v
GO

DROP VIEW IF EXISTS risk_score_overview_v
GO

DROP VIEW IF EXISTS risk_score_schedule_v
GO

CREATE VIEW risk_score_overview_v AS
SELECT TOP 10
  cfg.entity_type,
  cfg.risk_score_type,
  CONVERT(varchar, cfg.update_time, 0) as updated_time_mod,
  cfg.update_time,
  ct.calculation_time,
  cfg.id,
  cfg.ops_sequence,
  rs.risk_score
FROM dbo.risk_score_cfg cfg
LEFT JOIN (SELECT 
           risk_score,
           calculation_time,
           entity_type,
       entity_unique_id
           FROM (SELECT 
         risk_score,
         calculation_time,
         entity_type,
         entity_unique_id,
         rank() over (partition by entity_unique_id order by calculation_time desc) rnk
         FROM risk_score
         WHERE entity_type = 'GOVERNANCE') rs_1
       WHERE rnk = 1) rs on rs.entity_type = cfg.entity_type
JOIN (SELECT
    entity_type,
    MAX(calculation_time) AS calculation_time
    FROM risk_score
    GROUP BY entity_type) ct ON ct.entity_type = cfg.entity_type
ORDER BY cfg.id desc
GO

CREATE VIEW risk_score_calculation_v AS
SELECT 
rfscfg.operation,
rfscfg.lower_limit,
rfscfg.upper_limit,
rfscfg.factor_weight,
rfs.base_rf_score,
rfs.ranged_rf_score,
rfs.weighted_rf_score,
rfs.calculation_time,
rfscfg.rfsc_version,
rfscfg.factor_unique_id,
rfscfg.deleted,
rfscfg.update_time,
rfscfg.creation_time,
rfscfg.id,
rfscfg.factor_attr_key,
rfscfg.risk_condition,
rfscfg.max_risk_increment,
CASE WHEN SUBSTRING(factor_unique_id, 1, 1) = 'G' THEN 'GOVERNANCE'
WHEN SUBSTRING(factor_unique_id, 1, 1) = 'U' THEN 'USER' 
WHEN SUBSTRING(factor_unique_id, 1, 1) = 'A' THEN 'APPLICATION' END AS entity_type
FROM risk_factor_score_cfg rfscfg
RIGHT JOIN (SELECT 
      base_rf_score,
            ranged_rf_score,
            weighted_rf_score,
            rf_unique_id,
            rfs_cfg_id,
            calculation_time,
            entity_type
      FROM (SELECT DISTINCT rf_unique_id, 
                  calculation_time, 
                  base_rf_score, 
                  ranged_rf_score, 
                  weighted_rf_score, 
                  rfs_cfg_id, 
                  entity_type,
                  row_number() over (partition by rf_unique_id order by calculation_time desc) rnk
                  FROM risk_factor_score) AS rs_1
          WHERE rnk = 1) rfs ON rfs.rfs_cfg_id = rfscfg.id
WHERE rfscfg.deleted = 0
GO

CREATE VIEW risk_score_schedule_v AS
SELECT 
  active,
    name,
    publish,
    unique_id,
    job_trigger,
    job_schedule_kind,
    entity_type,
    last_day_of_month,
    repeat,
    start_date,
    time_zone_id,
  description,
  end_date,
  interval,
  interval_unit,
  jt.cron_spec
FROM job_schedule js
JOIN job_trigger jt ON jt.qs_trigger_name = js.qs_job_name
WHERE job_schedule_kind = 'RISK_SCORING'
GO

GRANT SELECT ON risk_score_calculation_v TO ig_report_role
GO

GRANT SELECT ON risk_score_overview_v TO ig_report_role
GO

GRANT SELECT ON risk_score_schedule_v TO ig_report_role
GO