BEGIN
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'RISK_SCORE_OVERVIEW_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM RISK_SCORE_OVERVIEW_V';
  END LOOP;
   FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'RISK_SCORE_OVERVIEW_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW RISK_SCORE_OVERVIEW_V';
  END LOOP;

  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'RISK_SCORE_CALCULATION_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM RISK_SCORE_CALCULATION_V';
  END LOOP;
   FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'RISK_SCORE_CALCULATION_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW RISK_SCORE_CALCULATION_V';
  END LOOP;

    FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'RISK_SCORE_SCHEDULE_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM RISK_SCORE_SCHEDULE_V';
  END LOOP;
   FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'RISK_SCORE_SCHEDULE_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW RISK_SCORE_SCHEDULE_V';
  END LOOP;

END;
/

CREATE VIEW risk_score_calculation_v AS
  SELECT
  rfscfg.operation,
  rfscfg.lower_limit,
  rfscfg.upper_limit,
  rfscfg.factor_weight,
  rfs.base_rf_score,
  rfs.ranged_rf_score,
  rfs.weighted_rf_score,
  rfs.calculation_time,
  rfscfg.rfsc_version,
  rfscfg.update_time,
  rfscfg.creation_time,
  rfscfg.deleted,
  rfscfg.id,
  rfscfg.factor_attr_key,
  rfscfg.risk_condition,
  rfscfg.factor_unique_id,
  CASE WHEN SUBSTR(factor_unique_id, 1, 1) = 'G' THEN 'GOVERNANCE'
  WHEN SUBSTR(factor_unique_id, 1, 1) = 'U' THEN 'USER' 
  WHEN SUBSTR(factor_unique_id, 1, 1) = 'A' THEN 'APPLICATION' END AS entity_type
FROM risk_factor_score_cfg rfscfg
RIGHT JOIN (SELECT 
            base_rf_score,
            ranged_rf_score,
            weighted_rf_score,
            rf_unique_id,
            rfs_cfg_id,
            calculation_time,
            entity_type
            FROM (SELECT rf_unique_id, 
                  calculation_time, 
                  base_rf_score, 
                  ranged_rf_score, 
                  weighted_rf_score, 
                  rfs_cfg_id, 
                  entity_type,
                  rank() over (partition by rf_unique_id order by calculation_time desc) rnk
                  FROM risk_factor_score)
                  WHERE rnk = 1) rfs ON rfs.rfs_cfg_id = rfscfg.id
WHERE rfscfg.deleted = 0;

CREATE VIEW risk_score_overview_v AS
 SELECT 
  cfg.entity_type,
  cfg.risk_score_type,
  TO_CHAR(cfg.update_time, 'DD-MON-YY HH12:MI') as updated_time_mod,
  cfg.update_time,
  ct.calculation_time,
  cfg.id,
  cfg.ops_sequence,
  rs.risk_score
FROM risk_score_cfg cfg
LEFT JOIN (SELECT
           risk_score,
           calculation_time,
           entity_type,
           entity_unique_id
           FROM (SELECT 
                   risk_score,
                   calculation_time,
                   entity_type,
                   entity_unique_id,
                   rank() over (partition by entity_unique_id order by calculation_time desc) rnk
                   FROM risk_score
                   WHERE entity_type = 'GOVERNANCE')
           WHERE rnk = 1) rs ON rs.entity_type = cfg.entity_type
     JOIN (SELECT
           entity_type,
           max(calculation_time) AS calculation_time
           FROM risk_score
          GROUP BY entity_type) ct ON ct.entity_type = cfg.entity_type;


CREATE VIEW risk_score_schedule_v AS
SELECT 
  active,
    name,
    publish,
    unique_id,
    job_trigger,
    job_schedule_kind,
    entity_type,
    last_day_of_month,
    repeat,
    start_date,
    time_zone_id,
  description,
  end_date,
  interval,
  interval_unit,
  jt.cron_spec
FROM job_schedule js
JOIN job_trigger jt ON jt.qs_trigger_name = js.qs_job_name
WHERE job_schedule_kind = 'RISK_SCORING';


GRANT SELECT ON igops.risk_score_overview_v TO ig_report_role;
CREATE PUBLIC SYNONYM risk_score_overview_v FOR igops.risk_score_overview_v;

GRANT SELECT ON igops.risk_score_schedule_v TO ig_report_role;
CREATE PUBLIC SYNONYM risk_score_schedule_v FOR igops.risk_score_schedule_v;

GRANT SELECT ON igops.risk_score_calculation_v TO ig_report_role;
CREATE PUBLIC SYNONYM risk_score_calculation_v FOR igops.risk_score_calculation_v;